Collate class

SQLite collation sequences.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

binary → const String
Case-sensitive comparison (default).
noCase → const String
Case-insensitive comparison.
rtrim → const String
Comparison ignoring trailing whitespace.