SqlFunc class

Annotation to mark a custom Dart function as a SQLite custom function.

The generator will scan all functions marked with @SqlFunc and:

  1. Create a list of custom SQL function registrations in custom_functions.g.dart.
  2. Generate type-safe PhormColumn extension methods for calling this function.

Constructors

SqlFunc({String? name})
Creates a @SqlFunc annotation, optionally overriding the SQL name.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
The SQLite-native name of the custom SQL function. If null, the generator defaults to the UPPERCASE version of the Dart function name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited