SqlFunctions class
Helper class to apply registered SQL functions to database columns in a type-safe way.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
apply<
T, R> (String functionName, PhormColumn< T> col) → PhormColumn<R> - Applies any SQL function to a column.